from django.contrib import admin
from bigsansar.contrib.advance.models import css, javascript
# Register your models here.

class admincss(admin.ModelAdmin):
    pass
class adminjava(admin.ModelAdmin):
    pass

admin.site.register(javascript, adminjava)
admin.site.register(css,admincss)





from django.db import models
from bigsansar.contrib.sites.models import domains
from django.contrib.auth.models import User

# Create your models here.

class css(models.Model):
    domain = models.OneToOneField(domains, on_delete=models.CASCADE)
    css = models.TextField()
    user = models.ForeignKey(User, on_delete=models.CASCADE)

    def __str__(self):
        return self.domain.domain

    class Meta:
        verbose_name = 'Css'
        verbose_name_plural = 'Custom Css'

    def get_absolute_url(self):
        return "http://%s/styles.css" % (self.domain,)
    

class javascript(models.Model):
     domain = models.OneToOneField(domains, on_delete=models.CASCADE)
     javascript = models.TextField()
     user = models.ForeignKey(User, on_delete=models.CASCADE)

     def __str__(self):
         return self.domain.domain
     
     class Meta:
         verbose_name = 'Javascripts'
         verbose_name_plural = 'JavaScripts'
         
         
     def get_absolute_url(self):
         return "http://%s/script.js" % (self.domain,)
     



# Generated by Django 4.2 on 2023-05-05 00:37

import ckeditor_uploader.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('blogs', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='post',
            name='thumbnails',
        ),
        migrations.AlterField(
            model_name='post',
            name='body',
            field=ckeditor_uploader.fields.RichTextUploadingField(),
        ),
    ]
